@@ -1,31 +1,35 @@
-#!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 """
 BitBake 'Fetch' implementations
 
-Classes for obtaining upstream sources for the
-BitBake build tools.
+This implementation is for svn. It is based on the cvs implementation.
 
-Copyright (C) 2003, 2004  Chris Larson
-
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place, Suite 330, Boston, MA 02111-1307 USA. 
-
-Based on functions from the base bb module, Copyright 2003 Holger Schurig
 """
 
+# Copyright (C) 2004 Marcin Juszkiewicz
+#
+#   Classes for obtaining upstream sources for the
+#   BitBake build tools.
+#   Copyright (C) 2003, 2004  Chris Larson
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+# Based on functions from the base bb module, Copyright 2003 Holger Schurig
+
 import os, re
+import sys
 import bb
 from   bb import data
 from   bb.fetch import Fetch
@@ -59,6 +63,12 @@ class Svn(Fetch):
 
         date = Fetch.getSRCDate(d)
 
+        if 'srcdate' in parm:
+            date = parm['srcdate']
+
+        if revision:
+            date = ""
+
         return os.path.join(data.getVar("DL_DIR", d, 1),data.expand('%s_%s_%s_%s_%s.tar.gz' % ( module.replace('/', '.'), host, path.replace('/', '.'), revision, date), d))
     localpath = staticmethod(localpath)
 
@@ -91,13 +101,31 @@ class Svn(Fetch):
 
 #           setup svn options
             options = []
-            if 'rev' in parm:
-                revision = parm['rev']
-            else:
-                revision = ""
 
             date = Fetch.getSRCDate(d)
 
+            if 'srcdate' in parm:
+                date = parm['srcdate']
+
+            revision = ""
+            if 'rev' in parm:
+                revision = parm['rev']
+            
+            if revision:
+                options.append("-r %s" % revision)
+            elif date != "now":
+                options.append("-r {%s}" % date)
+
+            if revision:
+                date = ""
+
+
+            if user:
+                options.append("--username %s" % user)
+
+            if pswd:
+                options.append("--password %s" % pswd)
+
             if "proto" in parm:
                 proto = parm["proto"]
             else:
@@ -121,44 +149,38 @@ class Svn(Fetch):
 
             svnroot = host + path
 
-            data.setVar('SVNROOT', svnroot, localdata)
+            data.setVar('SVNROOT', "%s://%s/%s" % (proto, svnroot, module), localdata)
             data.setVar('SVNCOOPTS', " ".join(options), localdata)
             data.setVar('SVNMODULE', module, localdata)
             svncmd = data.getVar('FETCHCOMMAND', localdata, 1)
-            svncmd = "svn co -r {%s} %s://%s/%s" % (date, proto, svnroot, module)
-
-            # either use the revision or if SRCDATE is now no braces
-            if revision:
-                svncmd = "svn co -r %s %s://%s/%s" % (revision, proto, svnroot, module)
-            elif date == "now":
-                svncmd = "svn co %s://%s/%s" % (proto, svnroot, module)
+            svnupcmd = data.getVar('UPDATECOMMAND', localdata, 1)
 
             if svn_rsh:
                 svncmd = "svn_RSH=\"%s\" %s" % (svn_rsh, svncmd)
+                svnupcmd = "svn_RSH=\"%s\" %s" % (svn_rsh, svnupcmd)
 
-#           create temp directory
-            bb.debug(2, "Fetch: creating temporary directory")
-            bb.mkdirhier(data.expand('${WORKDIR}', localdata))
-            data.setVar('TMPBASE', data.expand('${WORKDIR}/oesvn.XXXXXX', localdata), localdata)
-            tmppipe = os.popen(data.getVar('MKTEMPDIRCMD', localdata, 1) or "false")
-            tmpfile = tmppipe.readline().strip()
-            if not tmpfile:
-                bb.error("Fetch: unable to create temporary directory.. make sure 'mktemp' is in the PATH.")
-                raise FetchError(module)
+            pkg = data.expand('${PN}', d)
+            pkgdir = os.path.join(data.expand('${SVNDIR}', localdata), pkg)
+            moddir = os.path.join(pkgdir, module)
+            bb.debug(2, "Fetch: checking for module directory '%s'" % moddir)
 
-#           check out sources there
-            os.chdir(tmpfile)
-            bb.note("Fetch " + loc)
-            bb.debug(1, "Running %s" % svncmd)
-            myret = os.system(svncmd)
+            if os.access(os.path.join(moddir, '.svn'), os.R_OK):
+                bb.note("Update " + loc)
+                # update sources there
+                os.chdir(moddir)
+                bb.debug(1, "Running %s" % svnupcmd)
+                myret = os.system(svnupcmd)
+            else:
+                bb.note("Fetch " + loc)
+#               check out sources there
+                bb.mkdirhier(pkgdir)
+                os.chdir(pkgdir)
+                bb.debug(1, "Running %s" % svncmd)
+                myret = os.system(svncmd)
             if myret != 0:
-                try:
-                    os.rmdir(tmpfile)
-                except OSError:
-                    pass
                 raise FetchError(module)
 
-            os.chdir(os.path.join(tmpfile, os.path.dirname(module)))
+            os.chdir(pkgdir)
 #           tar them up to a defined filename
             myret = os.system("tar -czf %s %s" % (os.path.join(dldir,tarfn), os.path.basename(module)))
             if myret != 0:
@@ -166,7 +188,5 @@ class Svn(Fetch):
                     os.unlink(tarfn)
                 except OSError:
                     pass
-#           cleanup
-            os.system('rm -rf %s' % tmpfile)
             os.chdir(olddir)
         del localdata
